\name{awe}
\alias{awe}
\title{
Approximate weight of evidence for model-based hierarchical clustering.
}
\description{
Computes a Bayesian criterion for assessing the number of clusters present
in the data.
}
\usage{
awe(tree, data)


}
\arguments{
\item{tree}{
an \code{mhtree} object.
}
\item{data}{
the data used to produce the \code{mhtree} object.
}}
\value{
the approximate weight of evidence for each possible stage of merging.
}
\section{NOTES}{
Since \code{mhtree} allows stopping and
starting at any stage, the result will contain NAs for those stages that have 
been eliminated. 
If you scaled your data before using \code{mhtree}, be sure
to use the same scaling when supplying the data to \code{awe}.
}
\references{
J. D. Banfield and A. E. Raftery, Model-based Gaussian and non-Gaussian
Clustering, \emph{Biometrics, }49:803-821 (1993).
}
\seealso{
\code{\link{mhtree}}, \code{\link{loglik}}
}
\examples{
data(iris)
iris.m _ iris[,1:4]
awe.val <- awe(mhtree(iris.m), iris.m)
plot(awe.val)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.




\name{bic}
\alias{bic}
\alias{bic.EI}
\alias{bic.VI}
\alias{bic.EEE}
\alias{bic.EEV}
\alias{bic.VEV}
\alias{bic.VVV}
\title{
BIC for parameterized MVN mixture models
}
\description{
Bayesian Information Criterion for MVN mixture models with possibly one 
Poisson noise term.
}

\usage{
bic(data, modelid, ...)
}

\arguments{
\item{data}{
matrix of observations.
}
\item{modelid}{
An integer specifying a parameterization of the MVN covariance matrix
defined by volume, shape and orientation charactertistics of the
underlying clusters. The allowed values for \code{modelid} and their
interpretation are as follows: \code{"EI"} : uniform spherical,
\code{"VI"} : spherical, \code{"EEE"} : uniform variance, \code{"VVV"} :
unconstrained variance, \code{"EEV"} : uniform shape and volume,
\code{"VEV"} : uniform shape.
}
\item{...}{
other arguments, including a quantity \code{eps} for determining singularity
in the covariance. The precise 
definition of \code{eps} varies the parameterization, each of which has
a default. 

Furthermore \code{z}, a matrix of conditional
probabilities. \code{z} should have a row for each observation in
\code{data}, and a column for each component of the mixture. If \code{z}
is missing, a single cluster is assumed (all noise if \code{noise = T}).

Next argument: \code{equal}, a logical variable indicating whether or
not the mixing proportions are equal in the model. The default is to
assume they are unequal.

The \code{noise} logical variable indicates whether or not to include a
Poisson noise term in the model. Default : \code{F}. 

Finally, \code{Vinv} gives
an estimate of the inverse hypervolume of the data region (needed only if
\code{noise = T}). Default : determined by the function \code{hypvol}.
}}
\value{
An object of class \code{"bic"} which is the Bayesian Information Criterion for the
given mixture model and given conditional probabilites. The model parameters 
and reciprocal condition estimate are returned as attributes.
}
\section{NOTE}{
The reciprocal condition estimate returned as an attribute ranges in value
between 0 and 1. The closer this estimate is to zero, the more likely it is
that the corresponding EM result (and BIC) are contaminated by roundoff error.
}
\references{
C. Fraley and A. E. Raftery, \emph{How many clusters? Which clustering method?
Answers via model-based cluster analysis. }Technical Report No. 329,
Dept. of Statistics, U. of Washington (February 1998).


R. Kass and A. E. Raftery, Bayes Factors. \emph{Journal of the American 
Statistical Association}90:773-795 (1995).
}
\seealso{
\code{\link{me}}, \code{\link{mstep}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "VVV"), 3)
z <- me( iris[,1:4], ctoz(cl), modelid = "VVV")
bic(iris[,1:4], modelid = "VVV", z = z)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{censcale}
\alias{censcale}
\title{
Centering and Scaling of Data
}
\description{
Transforms a data set by subtracting the column mean from each column and
dividing each column by the square root of its variance when the latter is
sufficiently large in magnitude.
}
\usage{
censcale(x, tol = 0.0001)


}
\arguments{
\item{x}{
Matrix of observations.
}
\item{tol}{
Threshold for column scaling. A column is divided by the square root of its
variance (standard deviation) when that quantity exceeds \code{tol}, The default
value is \code{0.0001}.
}}
\value{
The centered and scaled matrix of observations.
}
\examples{
data(iris)
iris.sc <- censcale(iris[,1:4])


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{chevron}
\alias{chevron}
\non_function{}
\title{Simulated minefield data}
\usage{data(chevron)}
\description{A two-dimensional data set of simulated minefield data
  (1104 observations).}
\references{C. Fraley and A.E. Raftery, \emph{Computer J.}, 41:578-588 (1998)}

\keyword{datasets}

\name{clpairs}
\alias{clpairs}
\title{
Classifications for hierarchical clustering.
}
\description{
Gives classifications corresponding to the stages of hierarchical clustering.
}
\usage{
clpairs(x, partition, col=partition, \dots)
}

\arguments{
\item{x}{
matrix of observations.
}
\item{partition}{
a vector of integers indicating a partition of the data.
}
\item{col}{
the default is to color the objects according to the partition.
}
\item{...}{
other arguments as specified by \code{pairs}
}}
\value{
a matrix whose columns are the classifications corresponding to each value of
\code{nclusters}.
}
\seealso{
\code{\link{pairs}}, \code{\link{mixproj}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid="VVV"), 3)
clpairs(iris[,1:4],cl)
}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.




\name{diabetes}
\alias{diabetes}
\alias{diabetes.class}
\non_function{}
\title{Diabetes data}
\usage{data(diabetes)}
\description{
Diabetes data from Reaven and Miller. Number of objects: 145; 3
variables. Three classes.
}
\references{G.M. Reaven and R.G. Miller, \emph{Diabetologica} 16:17-24 (1979).
  }

\keyword{datasets}
\name{emclust}
\alias{emclust}
\title{
BIC from hierarchical clustering followed by EM for several parameterized Gaussian mixture models.
}
\description{
Bayesian Information Criterion for various models and numbers of clusters
computed from hierarchical clustering followed by EM for several
parameterizations of Gaussian mixture models possibly with Poisson noise.
}
\usage{
emclust(data, nclus, modelid, k, equal=F, noise, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{nclus}{
An integer vector specifying the numbers of clusters for which the BIC is to
be calculated. Default: 1:9 without noise; 0:9 with noise.
}
\item{modelid}{
A vector of character strings indicating the models to be fitted.
The allowed values or \code{modelid} and their interpretation are as follows:
\code{"EI"} : uniform spherical, \code{"VI"} : spherical, \code{"EEE"} : uniform variance,
\code{"VVV"} : unconstrained variance, \code{"EEV"} : uniform shape and volume,
\code{"VEV"} : uniform shape.
The default is to fit all of the models.
}
\item{k}{
If \code{k} is specified, the hierarchical clustering phase will use a sample of
size \code{k} of the data in the initial hierarchical clustering phase. The
default is to use the entire data set.
}
\item{equal}{
Logical variable indicating whether or not the mixing proportions are
equal in the model. The default is to assume they are unequal.
}
\item{noise}{
A logical vector of length equal to the number of observations in the data,
whose elements indicate an initial estimate of noise (indicated by \code{T}) in
the data. By default, \code{emclust} fits Gaussian mixture models in which it is 
assumed there is no noise. If \code{noise} is specified, \code{emclust} will fit a 
Gaussian mixture with a Poisson term for noise in the EM phase.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{noise} is specified). Default : determined by function \code{hypvol}
}}
\value{
Bayesian Information Criterion for the six mixture models and specified
numbers of clusters. Auxiliary information returned as attributes.
}
\section{NOTE}{
The hierarchical clustering phase uses the unconstrained model.
The reciprocal condition estimate returned as an attribute ranges in value
between 0 and 1. The closer this estimate is to zero, the more likely it is
that the corresponding EM result (and BIC) are contaminated by roundoff error.
}
\references{
C. Fraley and A. E. Raftery, \emph{How many clusters? Which clustering method?
Answers via model-based cluster analysis. }Technical Report No. 329,
Dept. of Statistics, U. of Washington (February 1998).


R. Kass and A. E. Raftery, Bayes Factors. \emph{Journal of the American 
Statistical Association}90:773-795 (1995).
}
\seealso{
\code{\link{summary.emclust}}, \code{\link{emclust1}}, \code{\link{mhtree}}, \code{\link{me}}
}
\examples{
data(iris)
bicvals _ emclust(iris[,1:4], nclus=1:3, modelid=c("VVV","EEV","VEV"))

data(chevron)
noisevec _ rep(0, nrow(chevron))
noisevec[chevron[,2]>60] _ 1
bicvals _ emclust(chevron, noise=noisevec)
sumry _ summary(bicvals, chevron)
plot(chevron, col=ztoc(sumry$z), pch=ztoc(sumry$z))
}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{emclust1}
\alias{emclust1}
\title{
BIC from hierarchical clustering followed by EM for a parameterized Gaussian mixture model.
}
\description{
Bayesian Information Criterion for various numbers of clusters computed from 
hierarchical clustering followed by EM for a selected parameterization
of Gaussian mixture models possibly with Poisson noise.
}
\usage{
emclust1(data, nclus, modelid, k, equal=F, noise, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{nclus}{
An integer vector specifying the numbers of clusters for which the BIC is to
be calculated. Default: 1:9 without noise; 0:9 with noise.
}
\item{modelid}{
An integer or vector of two integers specifying the model(s) to be used
in the hierarchical clustering and EM phases of the BIC
calculations. The allowed values or \code{modelid} and their
interpretation are as follows: \code{"EI"} : uniform spherical,
\code{"VI"} : spherical, \code{"EEE"} : uniform variance, \code{"VVV"} :
unconstrained  variance, \code{"EEV"} : uniform shape and volume,
\code{"VEV"} : uniform shape. 

Default: \code{c("VVV","VVV")} (unconstrained variance for both phases)
}
\item{k}{
If \code{k} is specified, the hierarchical clustering phase will use a
sample of size \code{k} of the data in the initial hierarchical
clustering phase. The default is to use the entire data set.  
}
\item{equal}{
Logical variable indicating whether or not the mixing proportions are
equal in the model. The default is to assume they are unequal.
}
\item{noise}{
A logical vector of length equal to the number of observations in the
data, whose elements indicate an initial estimate of noise (indicated by
\code{T}) in the data. By default, \code{emclust1} fits Gaussian mixture
models in which it is assumed there is no noise. If \code{noise} is
specified, \code{emclust1} will fit a Gaussian mixture with a Poisson
term for noise in the EM phase. 
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only
if \code{noise} is specified). Default : determined by the function
\code{hypvol}. 
}}
\value{
Bayesian Information Criterion for the six mixture models and specified
numbers of clusters. Auxiliary information returned as attributes.
}
\section{NOTE}{
The reciprocal condition estimate returned as an attribute ranges in value
between 0 and 1. The closer this estimate is to zero, the more likely it is
that the corresponding EM result (and BIC) are contaminated by roundoff error.
}
\references{
C. Fraley and A. E. Raftery, \emph{How many clusters? Which clustering method?
Answers via model-based cluster analysis. }Technical Report No. 329,
Dept. of Statistics, U. of Washington (February 1998).


R. Kass and A. E. Raftery, Bayes Factors. \emph{Journal of the American 
Statistical Association}90:773-795 (1995).
}
\seealso{
\code{\link{summary.emclust1}}, \code{\link{emclust}}, \code{\link{mhtree}}, \code{\link{me}}
}
\examples{
data(iris)
emclust1(iris[,1:4], nclus=2:3, modelid = c("VVV","EEV"))

data(chevron)
noisevec _ rep(0, nrow(chevron))
noisevec[chevron[,2]>60] _ 1
bicvals _ emclust1(chevron, noise=noisevec, nclus=0:5)
sumry _ summary(bicvals, chevron)
plot(chevron, col=ztoc(sumry$z), pch=ztoc(sumry$z))

}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{estep.EEE}
\alias{estep.EEE}
\title{
E-step for constant-variance MVN mixture models
}
\description{
E-step for estimating conditional probabilities from parameter estimates in an
MVN mixture model having constant variance and possibly one Poisson noise term.
}
\usage{
estep.EEE(data, mu, sigma, prob, eps, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{mu}{
matrix whose columns are the Gaussian group means.
}
\item{sigma}{
group variance matrix.
}
\item{prob}{
mixing proportions (probabilities) for each group. If \code{prob} is missing, 
the number of groups is assumed to be the number of columns in \code{mu} (no
noise). A Poisson noise term will appear in the conditional probabilities if
\code{length(prob)} is equal to \code{ncol(mu)+1}.
}
\item{eps}{
Lower bound on the reciprocal condition estimate for the covariance. 
Default : \code{.Machine$double.eps}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{prob} indicates a noise term). Default : determined by function \code{hypvol}
}}
\value{
the conditional probablilities corresponding to the parameter estimates.
The loglikelihood is returned as an attribute.
}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley
(1997).
}
\seealso{
\code{\link{estep}}, \code{\link{me.EEE}}, \code{\link{mstep.EEE}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "EEE"),3)
z <- me.EEE( iris[,1:4], ctoz(cl))
Mstep <- mstep.EEE(iris[,1:4], z)
estep.EEE( iris[,1:4], Mstep$mu, Mstep$sigma, Mstep$prob)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{estep.EI}
\alias{estep.EI}
\title{
E-step for spherical, constant-volume MVN mixture models
}
\description{
E-step for estimating conditional probabilities from parameter estimates in an
MVN mixture model having equal spherical variances and possibly one Poisson
noise term.
}
\usage{
estep.EI(data, mu, sigma, prob, eps, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{mu}{
matrix whose columns are the Gaussian group means.
}
\item{sigma}{
variance.
}
\item{prob}{
mixing proportions (probabilities) for each group. If \code{prob} is missing, 
the number of groups is assumed to be the number of columns in \code{mu} (no
noise). A Poisson noise term will appear in the conditional probabilities if
\code{length(prob)} is equal to \code{ncol(mu)+1}.
}
\item{eps}{
Lower bound on the estimated values of sigma-squared.
Default : \code{.Machine$double.eps}
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{prob} indicates a noise term). Default : determined by function \code{hypvol}
}}
\value{
the conditional probablilities corresponding to the parameter estimates.
The loglikelihood is returned as an attribute.
}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley
(1997).
}
\seealso{
\code{\link{estep}}, \code{\link{me.EI}}, \code{\link{mstep.EI}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "EI"),3)
z <- me.EI( iris[,1:4], ctoz(cl))
Mstep <- mstep.EI(iris[,1:4], z)
estep.EI( iris[,1:4], Mstep$mu, Mstep$sigma, Mstep$prob)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{estep}
\alias{estep}
\title{
E-step for parameterized MVN mixture models
}
\description{
E-step for estimating conditional probabilities from parameter estimates in an
MVN mixture model having possibly one Poisson noise term.
}
\usage{
estep(data, modelid, mu, \dots)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{modelid}{
An integer specifying a parameterization of the MVN covariance matrix defined 
by volume, shape and orientation charactertistics of the underlying clusters. 
The allowed values for \code{modelid} and their interpretation are as follows:
\code{"EI"} : uniform spherical, \code{"VI"} : spherical, \code{"EEE"} : uniform variance,
\code{"VVV"} : unconstrained variance, \code{"EEV"} : uniform shape and volume,
\code{"VEV"} : uniform shape.
}
\item{mu}{
matrix whose columns are the Gaussian group means.
}
\item{...}{
additional arguments, as follows:
}
\item{sigmasq}{
}
\item{sigma}{
group variances (\code{sigmasq} - spherical models) or covariances (\code{sigma} -
elliposidal models)
}
\item{prob}{
mixing proportions (probabilities) for each group. If \code{prob} is missing, 
the number of groups is assumed to be the number of columns in \code{mu} (no
noise). A Poisson noise term will appear in the conditional probabilities if
\code{length(prob)} is equal to \code{ncol(mu)+1}.
}
\item{eps}{
Tolerance for determining singularity in the covariance matrix. The precise
definition of \code{eps} varies the parameterization, each of which has a default.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{prob} indicates a noise term). Default : determined by function \code{hypvol}
}}
\value{
the conditional probablilities corresponding to the parameter estimates.
The loglikelihood is returned as an attribute.
}
\section{NOTE}{
The reciprocal condition estimate returned as an attribute ranges in value
between 0 and 1. The closer this estimate is to zero, the more likely it is
that the corresponding EM result (and BIC) are contaminated by roundoff error.
}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley
(1997).
}
\seealso{
\code{\link{me}}, \code{\link{mstep}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid="VI"), 3)
z <- me( iris[,1:4], ctoz(cl), modelid = "VI")
pars <- mstep( iris[,1:4], modelid = "VI", z)
estep(iris[,1:4], modelid = "VI", pars$mu, pars$sigma, pars$prob)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{estep.VI}
\alias{estep.VI}
\title{
E-step for spherical, varying volume MVN mixture models
}
\description{
E-step for estimating conditional probabilities from parameter estimates
in an MVN mixture model having varying spherical variances and possibly
one Poisson noise term. 
}
\usage{
estep.VI(data, mu, sigma, prob, eps, Vinv)
}
\arguments{
\item{data}{
matrix of observations.
}
\item{mu}{
matrix whose columns are the Gaussian group means.
}
\item{sigma}{
group variances.
}
\item{prob}{
mixing proportions (probabilities) for each group. If \code{prob} is missing, 
the number of groups is assumed to be the number of columns in \code{mu} (no
noise). A Poisson noise term will appear in the conditional probabilities if
\code{length(prob)} is equal to \code{ncol(mu)+1}.
}
\item{eps}{
Lower bound on the estimated values of sigma-squared.
Default : \code{.Machine$double.eps}
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{prob} indicates a noise term). Default : determined by function \code{hypvol}
}}
\value{
the conditional probablilities corresponding to the parameter estimates.
The loglikelihood is returned as an attribute.
}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley
(1997).
}
\seealso{
\code{\link{estep}}, \code{\link{me.VI}}, \code{\link{mstep.VI}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "VI"),3)
z <- me.VI( iris[,1:4], ctoz(cl))
Mstep <- mstep.VI(iris[,1:4], z)
estep.VI( iris[,1:4], Mstep$mu, Mstep$sigma, Mstep$prob)

}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{estep.VVV}
\alias{estep.VVV}
\title{
E-step for constant-variance MVN mixture models
}
\description{
E-step for estimating conditional probabilities from parameter estimates in an
MVN mixture model having constant variance and possibly one Poisson noise term.
}
\usage{
estep.VVV(data, mu, sigma, prob, eps, Vinv)
}
\arguments{
\item{data}{
matrix of observations.
}
\item{mu}{
matrix whose columns are the Gaussian group means.
}
\item{sigma}{
group variance matrices.
}
\item{prob}{
mixing proportions (probabilities) for each group. If \code{prob} is missing, 
the number of groups is assumed to be the number of columns in \code{mu} (no
noise). A Poisson noise term will appear in the conditional probabilities if
\code{length(prob)} is equal to \code{ncol(mu)+1}.
}
\item{eps}{
Lower bound on the reciprocal condition estimate for the covariance. 
Default : \code{Machine$double.eps}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{prob} indicates a noise term).
Default : determined by function \code{hypvol}
}}
\value{
the conditional probablilities corresponding to the parameter estimates.
The loglikelihood is returned as an attribute.
}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley
(1997).
}
\seealso{
\code{\link{estep}}, \code{\link{me.VVV}}, \code{\link{mstep.VVV}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "VVV"),3)
z <- me.VVV( iris[,1:4], ctoz(cl))
Mstep <- mstep.VVV(iris[,1:4], z)
estep.VVV( iris[,1:4], Mstep$mu, Mstep$sigma, Mstep$prob)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{estep.XEV}
\alias{estep.XEV}
\title{
E-step for constant shape MVN mixture models
}
\description{
E-step for estimating conditional probabilities from parameter estimates in an
MVN mixture model having constant shape and possibly one Poisson noise term.
}
\usage{
estep.XEV(data, mu, sigma, prob, eps, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{mu}{
matrix whose columns are the Gaussian group means.
}
\item{sigma}{
group variance matrices.
}
\item{prob}{
mixing proportions (probabilities) for each group. If \code{prob} is missing, 
the number of groups is assumed to be the number of columns in \code{mu} (no
noise). A Poisson noise term will appear in the conditional probabilities if
\code{length(prob)} is equal to \code{ncol(mu)+1}.
}
\item{eps}{
A 2-vector specifying lower bounds on the pth root of the volume of the
ellipsoids defining the clusters, where p is the data dimension, and on the
reciprocal condition number for the estimated shape of the covariance estimate.
Default : \code{c(.Machine$double.eps, .Machine$double.eps)}
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{prob} indicates a noise term). Default : determined by function \code{hypvol}
}}
\value{
the conditional probablilities corresponding to the parameter estimates.
The loglikelihood is returned as an attribute.
}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley
(1997).
}
\seealso{
\code{\link{estep}}, \code{\link{me.EEV}}, \code{\link{me.VEV}}, \code{\link{mstep.EEV}}, \code{\link{mstep.VEV}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "VVV"),3)
z <- me.EEV( iris[,1:4], ctoz(cl))
Mstep <- mstep.EEV(iris[,1:4], z)
estep.XEV( iris[,1:4], Mstep$mu, Mstep$sigma, Mstep$prob)




}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{hypvol}
\alias{hypvol}
\alias{pcvol}
\title{Estimation of hypervolume}
\description{
  Returns the minimum hypervolume. \code{pcvol} calculates this volume
  using principal components. \code{hypvol} takes the smaller of either
  this value, or a value calculated from the range of the data.
}

\usage{
hypvol(data, reciprocal=F)
pcvol(data, reciprocal=F)
}

\arguments{
  \item{data}{Data matrix.}
  \item{reciprocal}{A logical indicating whether the reciprocal volume
    is to be returned.}
}

\examples{
data(iris)
hypvol(iris[,1:4])
pcvol(iris[,1:4])
}

\keyword{cluster}
\name{loglik}
\alias{loglik}
\alias{loglik.EI}
\alias{loglik.VI}
\alias{loglik.EEE}
\alias{loglik.EFV}
\alias{loglik.VFV}
\alias{loglik.VVV}
\title{
Loglikelihood for model-based hierarchical clustering.
}
\description{
Gives the loglikelihood for each stage of model-based hierarchical clustering.
}
\usage{
loglik(tree, data, ...)
}
\arguments{
\item{tree}{
an \code{"mhtree"} object.
}
\item{data}{
the data used to produce the \code{"mhtree"} object.
}
\item{...}{Other arguments, depending on the method that is
appropriate. In particular \code{Vinv}, the approximate reciprocal
hypervolume of the region from which the data is drawn. The default (for
those methods that need this quantity) is determined by the function
\code{hypvol}.
}}
\value{
the loglikelihood corresponding to the initial partition and to each stage of 
merging in hierarchical clustering, together with the following attribute:

\item{nmerge}{
the number of clusters merged at each stage.
}}
\section{NOTES}{
The value given is equal to the loglikelihood up to an additive constant. 
For those models in which they arise, indeterminate terms are 
assigned the value \code{-k*log(volume)}, where \code{k} is the number of observations 
associated with the term. 
If you scaled your data before using \code{mhtree}, be 
sure to use the same scaling when supplying the data to \code{loglik}.
}
\seealso{
\code{\link{mhtree}}, \code{\link{awe}}
}
\examples{
data(iris)
loglik(mhtree(iris[,1:4]),iris[,1:4])
}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.




\name{me.EEE}
\alias{me.EEE}
\title{
EM for constant-variance MVN mixture models
}
\description{
EM iteration (M-step followed by E-step) for estimating parameters in an MVN 
mixture model having constant variance and possibly one Poisson noise term.
}
\usage{
me.EEE(data, z, eps, tol, itmax, equal = F, noise = F, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{z}{
matrix of conditional probabilities. \code{z} should have a row for each observation
in \code{data}, and a column for each component of the mixture.
}
\item{eps}{
Lower bound on the reciprocal condition estimate for the covariance estimate.
Default : \code{.Machine$double.eps}.
}
\item{tol}{
The iteration is terminated if the relative error in the loglikelihood value
falls below \code{tol}. Default : \code{sqrt(.Machine$double.eps)}.
}
\item{itmax}{
Upper limit on the number of iterations. Default : \code{Inf} (no upper limit).
}
\item{equal}{
Logical variable indicating whether or not to assume equal proportions in the
mixture. Default : \code{F}.
}
\item{noise}{
Logical variable indicating whether or not to include a Poisson noise term in
the model. Default : \code{F}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{noise = T}). Default : determined by function \code{hypvol}
}}
\value{
the conditional probablilities at the final iteration (information about the
iteration is included as attributes).
}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley
(1997).
}
\seealso{
\code{\link{me}}, \code{\link{mstep.EEE}}, \code{\link{estep.EEE}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "EEE"),3)
z <- me.EEE( iris[,1:4], ctoz(cl))
Mstep <- mstep.EEE(iris[,1:4], z)
estep.EEE( iris[,1:4], Mstep$mu, Mstep$sigma, Mstep$prob)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{me.EEV}
\alias{me.EEV}
\title{
EM for constant shape, constant volume MVN mixture models
}
\description{
EM iteration (M-step followed by E-step) for estimating parameters in an MVN
mixture model having constant shape, constant volume and possibly one Poisson 
noise term.
}
\usage{
me.EEV(data, z, eps, tol, itmax, equal = F, noise = F, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{z}{
matrix of conditional probabilities. \code{z} should have a row for each observation
in \code{data}, and a column for each component of the mixture.
}
\item{eps}{
A 2-vector specifying lower bounds on the pth root of the volume of the 
ellipsoids defining the clusters, where p is the data dimension, and on the 
reciprocal condition number for the estimated shape of the covariance 
estimates. Default : \code{c(.Machine$double.eps, .Machine$double.eps)}
If only one value is given it is assumed to override only the first
default.
}
\item{tol}{
The iteration is terminated if the relative error in the loglikelihood value
falls below \code{tol}. Default : \code{sqrt(.Machine$double.eps)}.
}
\item{itmax}{
Upper limit on the number of iterations. Default : \code{Inf} (no upper limit).
}
\item{equal}{
Logical variable indicating whether or not to assume equal proportions in the
mixture. Default : \code{F}.
}
\item{noise}{
Logical variable indicating whether or not to include a Poisson noise term in
the model. Default : \code{F}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{noise = T}). Default : determined by function \code{hypvol}
}}
\value{
the conditional probablilities at the final iteration (information about the
iteration is included as attributes).
}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley
(1997).
}
\seealso{
\code{\link{me}}, \code{\link{mstep.EEV}}, \code{\link{estep.XEV}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "VVV"),3)
me.EEV( iris[,1:4], ctoz(cl))


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.




\name{me.EI}
\alias{me.EI}
\title{
EM for spherical, constant-volume MVN mixture models
}
\description{
EM iteration (M-step followed by E-step) for estimating parameters in an
MVN mixture model having equal spherical variances and possibly one Poisson 
noise term.
}
\usage{
me.EI(data, z, eps, tol, itmax, equal = F, noise = F, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{z}{
matrix of conditional probabilities. \code{z} should have a row for each observation
in \code{data}, and a column for each component of the mixture.
}
\item{eps}{
Lower bound on the estimated values of sigma-squared.  
Default : \code{.Machine$double.eps}
}
\item{tol}{
The iteration is terminated if the relative error in the loglikelihood value
falls below \code{tol}. Default : \code{sqrt(.Machine$double.eps)}.
}
\item{itmax}{
Upper limit on the number of iterations. Default : \code{Inf} (no upper limit).
}
\item{equal}{
Logical variable indicating whether or not to assume equal proportions in the
mixture. Default : \code{F}.
}
\item{noise}{
Logical variable indicating whether or not to include a Poisson noise term in
the model. Default : \code{F}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{noise = T}). Default : determined by function \code{hypvol}
}}
\value{
the conditional probablilities at the final iteration (information about the
iteration is included as attributes).
}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley,
(1997).
}
\seealso{
\code{\link{me}}, \code{\link{mstep.EI}}, \code{\link{estep.EI}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "EI"),3)
z <- me.EI( iris[,1:4], ctoz(cl))
Mstep <- mstep.EI(iris[,1:4], z)
estep.EI( iris[,1:4], Mstep$mu, Mstep$sigma, Mstep$prob)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{me}
\alias{me}
\title{
EM for parameterized MVN mixture models
}
\description{
EM iteration (M-step followed by E-step) for estimating parameters in an 
MVN mixture model with possibly one Poisson noise term.
}
\usage{
me(data, modelid, z, \dots)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{modelid}{
An integer specifying a parameterization of the MVN covariance matrix defined 
by volume, shape and orientation charactertistics of the underlying clusters. 
The allowed values for \code{modelid} and their interpretation are as follows:
\code{"EI"} : uniform spherical, \code{"VI"} : spherical, \code{"EEE"} : uniform variance,
\code{"VVV"} : unconstrained variance, \code{"EEV"} : uniform shape and volume,
\code{"VEV"} : uniform shape.
}
\item{z}{
matrix of conditional probabilities. \code{z} should have a row for each observation
in \code{data}, and a column for each component of the mixture.
}
\item{...}{
additional arguments, as follows:
}
\item{eps}{
Tolerance for determining singularity in the covariance matrix. The precise 
definition of \code{eps} varies the parameterization, each of which has a default.
}
\item{tol}{
The iteration is terminated if the relative error in the loglikelihood value
falls below \code{tol}. Default : \code{sqrt(.Machine$double.eps)}.
}
\item{itmax}{
Upper limit on the number of iterations. Default : \code{Inf} (no upper limit).
}
\item{equal}{
Logical variable indicating whether or not to assume equal proportions in the
mixture. Default : \code{F}.
}
\item{noise}{
Logical variable indicating whether or not to include a Poisson noise term in
the model. Default : \code{F}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{noise = T}). Default : determined by function \code{hypvol}
}}
\value{
the conditional probablilities at the final iteration (information about the
iteration is included as attributes).
}
\section{NOTE}{
The reciprocal condition estimate returned as an attribute ranges in value
between 0 and 1. The closer this estimate is to zero, the more likely it is
that the corresponding EM result (and BIC) are contaminated by roundoff error.
}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley,
(1997).
}
\seealso{
\code{\link{mstep}}, \code{\link{estep}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "VVV"),3)
me( iris[,1:4], modelid = "VVV", ctoz(cl))


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{me.VEV}
\alias{me.VEV}
\title{
EM for constant shape, varying volume MVN mixture models
}
\description{
EM iteration (M-step followed by E-step) for estimating parameters in an MVN
mixture model having constant shape, varying volume and possibly one Poisson 
noise term.
}
\usage{
me.VEV(data, z, eps, tol, itmax, equal = F, noise = F, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{z}{
matrix of conditional probabilities. \code{z} should have a row for each observation
in \code{data}, and a column for each component of the mixture.
}
\item{eps}{
A 2-vector specifying lower bounds on the pth root of the volume of the 
ellipsoids defining the clusters, where p is the data dimension, and on the 
reciprocal condition number for the estimated shape of the covariance 
estimates. Default : \code{c(.Machine$double.eps, .Machine$double.eps)}.
If only one value is given it is assumed to override only the first
default.
}
\item{tol}{
A 2 vector giving the tolerances for the outer (EM) and inner (volume and 
shape estimating) iterations. The outer iteration is terminated if the 
relative error in the loglikelihood value falls below \code{tol[1]}. 
The inner iteration is terminated if the relative error in both the estimate
of the pth root of the volume and the shape estimate falls below \code{tol[2]}.
Default: \code{c(sqrt(.Machine$double.eps), sqrt(.Machine$double.eps))}.
If only one value is given it is assumed to override only the first
default.
}
\item{itmax}{
A 2-vector giving an upper limit on the number of outer and inner iterations. 
Default : \code{c(Inf,Inf)} - no upper limit for outer or inner iterations.
If only one value is given it is assumed to override only the first
default.
}
\item{equal}{
Logical variable indicating whether or not to assume equal proportions in the
mixture. Default : \code{F}.
}
\item{noise}{
Logical variable indicating whether or not to include a Poisson noise term in
the model. Default : \code{F}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{noise = T}). Default : determined by function \code{hypvol}
}}
\value{
the conditional probablilities at the final iteration (information about the
iteration is included as attributes).
}
\section{NOTE}{
The default for inner iterations are set up so as to compute the true M-step
parameters at each iteration. However if you plan to run \code{me.VEV} to 
convergence, then it is usually safe to set the number of inner iterations to 
0, 1, or some small number.
}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley,
(1997).
}
\seealso{
\code{\link{me}}, \code{\link{mstep.VEV}}, \code{\link{estep.XEV}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4]),3)
z <- me.VEV( iris[,1:4], ctoz(cl))
mstep.VEV(iris[,1:4], z)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.




\name{me.VI}
\alias{me.VI}
\title{
EM for spherical, varying volume MVN mixture models
}
\description{
EM iteration (M-step followed by E-step) for estimating parameters in an
MVN mixture model having varying spherical variances and possibly one Poisson 
noise term.
}
\usage{
me.VI(data, z, eps, tol, itmax, equal = F, noise = F, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{z}{
matrix of conditional probabilities. \code{z} should have a row for each observation
in \code{data}, and a column for each component of the mixture.
}
\item{eps}{
Lower bound on the estimated values of sigma-squared. 
Default : \code{.Machine$double.eps}
}
\item{tol}{
The iteration is terminated if the relative error in the loglikelihood value
falls below \code{tol}. Default : \code{sqrt(.Machine$double.eps)}.
}
\item{itmax}{
Upper limit on the number of iterations. Default : \code{Inf} (no upper limit).
}
\item{equal}{
Logical variable indicating whether or not to assume equal proportions in the
mixture. Default : \code{F}.
}
\item{noise}{
Logical variable indicating whether or not to include a Poisson noise term in
the model. Default : \code{F}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{noise = T}). Default : determined by function \code{hypvol}
}}
\value{
the conditional probablilities at the final iteration (information about the
iteration is included as attributes).
}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley,
(1997).
}
\seealso{
\code{\link{me}}, \code{\link{mstep.VI}}, \code{\link{estep.VI}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "VI"),3)
z <- me.VI( iris[,1:4], ctoz(cl))
Mstep <- mstep.VI(iris[,1:4], z)
estep.VI( iris[,1:4], Mstep$mu, Mstep$sigma, Mstep$prob)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{me.VVV}
\alias{me.VVV}
\title{
EM for unconstrained MVN mixture models
}
\description{
EM iteration (M-step followed by E-step) for estimating parameters in an 
unconstrained MVN mixture model with possibly one Poisson noise term.
}
\usage{
me.VVV(data, z, eps, tol, itmax, equal = F, noise = F, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{z}{
matrix of conditional probabilities. \code{z} should have a row for each observation
in \code{data}, and a column for each component of the mixture.
}
\item{eps}{
Lower bound on the reciprocal condition estimate for the covariance estimate.
Default : \code{.Machine$double.eps}.
}
\item{tol}{
The iteration is terminated if the relative error in the loglikelihood value
falls below \code{tol}. Default : \code{sqrt(.Machine$double.eps)}.
}
\item{itmax}{
Upper limit on the number of iterations. Default : \code{Inf} (no upper limit).
}
\item{equal}{
Logical variable indicating whether or not to assume equal proportions in the
mixture. Default : \code{F}.
}
\item{noise}{
Logical variable indicating whether or not to include a Poisson noise term in
the model. Default : \code{F}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{noise = T}). Default : determined by function \code{hypvol}
}}
\value{
the conditional probablilities at the final iteration (information about the
iteration is included as attributes).
}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley,
(1997).
}
\seealso{
\code{\link{me}}, \code{\link{mstep.VVV}}, \code{\link{estep.VVV}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "VVV"),3)
z <- me.VVV( iris[,1:4], ctoz(cl))
Mstep <- mstep.VVV(iris[,1:4], z)
estep.VVV( iris[,1:4], Mstep$mu, Mstep$sigma, Mstep$prob)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{mhclass}
\alias{mhclass}
\title{
Classifications for hierarchical clustering.
}
\description{
Gives classifications corresponding to the stages of hierarchical clustering.
}
\usage{
mhclass(tree, nclusters)


}
\arguments{
\item{tree}{
An \code{"mhtree"} object, which is a matrix whose columns are integers 
corresponding to clusters merged at each stage of hierarchical clustering
(classification tree), together with an attribute giving the initial
partition for the hierarchical process.
}
\item{nclusters}{
the numbers of clusters for which classifications are desired. The default
is to produce all classifications implied by \code{tree} given the initial
partition.
}}
\value{
a matrix whose columns are the classifications corresponding to each value of
\code{nclusters}. Columns are labeled by the \code{as.character} representation of
the number of clusters.
}
\seealso{
\code{\link{mhtree}}
}
\examples{
data(iris)
mhclass(mhtree(iris[,1:4]), 2:6)
}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.




\name{mhtree.EEE}
\alias{mhtree.EEE}
\title{
Classification tree for hierarchical clustering for Gaussian models with constant variance.
}
\description{
Computes a classification tree for agglomerative hierarchical clustering using
a Gaussian model in which all clusters have the same volume, shape, and 
orientation.
}
\usage{
mhtree.EEE(data, partition, min.clusters = 1)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{partition}{
initial classification of the data. The default puts every observation in a
singleton cluster.
}
\item{min.clusters}{
minimum number of clusters desired. The default is to carry out agglomerative
hierarchical clustering until termination, that is, until all observations
belong to a single group. The default value is 1.
}}
\value{
an object of class \code{"mhclust"}, which consists of a classification tree with
the following attributes:

\item{call}{
a copy of the call to \code{mhclust.EEE}.
}
\item{determinant}{
value related to the determinant of the sum of sample crossproduct matrices,
which is the relevant criterion for the model, computed during the course of 
hierarchical clustering.
}
\item{dimensions}{
the data dimensions.
}
\item{initial.partition}{
the partition at which agglomerative hierarchical clustering is initiated.
}
\item{trace}{
the trace of the sum of sample crossproduct matrices produced during the
course of hierarchical clustering.
}}
\section{NOTES}{
The constant variance option is one of the slowest options for \code{mhclust},
because the model does not admit a fast hierarchical clustering algorithm.
At the same time, it is one of the more space-sefficient options.
}
\references{
J. D. Banfield and A. E. Raftery, Model-based Gaussian and non-Gaussian
Clustering, \emph{Biometrics, }49:803-821 (1993).


C. Fraley, \emph{Algorithms for Model-based Gaussian Hierarchical Clustering,
}Technical Report No. 311, Department of Statistics, University of
Washington (October 1996), to appear in
\emph{SIAM Journal on Scientific Computing}.


H. P. Friedman and J. Rubin, On some invariant criteria for grouping data,
\emph{Journal of the American Statistical Association, }62:1159-1178 (1967).
}
\seealso{
\code{\link{mhtree}}, \code{\link{mhclass}}, \code{\link{awe}}, \code{\link{partuniq}}
}
\examples{
data(iris)
mhtree.EEE(iris[,1:4])


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{mhtree.EFV}
\alias{mhtree.EFV}
\title{
Classification tree for hierarchical clustering for Gaussian models with equal volume and fixed shape.
}
\description{
Computes a classicification tree for agglomerative hierarchical clustering 
using a Gaussian model in which clusters have a fixed shape and are of equal 
volume.
}
\usage{
mhtree.EFV(data, partition, min.clusters = 1, shape)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{partition}{
initial classification of the data. The default puts every observation in a
singleton cluster.
}
\item{min.clusters}{
minimum number of clusters desired. The default is to carry out agglomerative
hierarchical clustering until termination, that is, until all observations
belong to a single group. The default value is 1.
}
\item{shape}{
positive vector of length equal to the dimension of the observations.
The values of \code{shape} should be proportional to the squares of the lengths
of the semi-major axes of the corresponding ellipsoid, and may be given in
any order. Note that \code{shape} is a required argument.
}}
\value{
an object of class \code{"mhtree"}, which consists of a classification tree with
the following attributes:

\item{call}{
a copy of the call to \code{mhtree.EFV}.
}
\item{change}{
value of the optimal change in likelihood at each stage.
}
\item{dimensions}{
the data dimensions.
}
\item{initial.partition}{
the partition at which agglomerative hierarchical clustering is initiated.
}}
\references{
J. D. Banfield and A. E. Raftery, Model-based Gaussian and non-Gaussian
Clustering, \emph{Biometrics, }49:803-821 (1993).


C. Fraley, \emph{Algorithms for Model-based Gaussian Hierarchical Clustering,
}Technical Report No. 311, Department of Statistics, University of
Washington (October 1996), to appear in
\emph{SIAM Journal on Scientific Computing}.


F. Murtagh and A. E. Raftery, Fitting straight lines to point patterns,
\emph{Pattern Recognition, }17:479-483 (1984).
}
\seealso{
\code{\link{mhtree}}, \code{\link{mhclass}}, \code{\link{awe}}, \code{\link{partuniq}}
}
\examples{
data(iris)
shape <- c(1,1/2,1/3)
mhtree.EFV(iris[,1:3], shape = shape)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{mhtree.EI}
\alias{mhtree.EI}
\title{
Classification tree for hierarchical clustering for Gaussian models with uniform diagonal variance.
}
\description{
Computes a classification tree for agglomerative hierarchical clustering using
a Gaussian model in which clusters are spherical and of equal volume (Wards' 
method).
}
\usage{
mhtree.EI(data, partition, min.clusters = 1)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{partition}{
initial classification of the data. The default puts every observation in a
singleton cluster.
}
\item{min.clusters}{
minimum number of clusters desired. The default is to carry out agglomerative
hierarchical clustering until termination, that is, until all observations
belong to a single group. The default value is 1.
}}
\value{
an object of class \code{"mhtree"}, which consists of a classification tree with
the following attributes:

\item{call}{
a copy of the call to \code{mhtree.EI}.
}
\item{change}{
value of the optimal change in likelihood at each stage.
}
\item{dimensions}{
the data dimensions.
}
\item{initial.partition}{
the partition at which agglomerative hierarchical clustering is initiated.
}}
\references{
J. D. Banfield and A. E. Raftery, Model-based Gaussian and non-Gaussian
Clustering, \emph{Biometrics, }49:803-821 (September 1993).


C. Fraley, \emph{Algorithms for Model-based Gaussian Hierarchical Clustering,
}Technical Report No. 311, Department of Statistics, University of
Washington (October 1996), to appear in
\emph{SIAM Journal on Scientific Computing}.


J. H. Ward, Hierarchical groupings to optimize and objective function,
\emph{Journal of the American Statistical Association, }58:234-244 (1963).
}
\seealso{
\code{\link{mhtree}}, \code{\link{mhclass}}, \code{\link{awe}}, \code{\link{partuniq}}
}
\examples{
data(iris)
mhtree.EI(iris[,1:4])


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{mhtree}
\alias{mhtree}
\alias{print.mhtree}
\title{
Classification Tree for Model-based Gaussian hierarchical clustering.
}
\description{
Determines a classification tree for agglomerative hierarchical
clustering using criteria based on parameterizations of Gaussian mixture
models that reflect the underlying geometry of the resulting clusters.
}
\usage{
mhtree(data, modelid, partition, min.clusters = 1, verbose = F, \dots)
print.mhtree(x, \dots)

}
\arguments{
\item{data}{
matrix of observations.
}
\item{modelid}{
An integer specifying a parameterization of the MVN covariance matrix defined 
by volume, shape and orientation charactertistics of the underlying clusters. 
The allowed values or \code{model} and their interpretation are as follows:
\code{"EI"} : uniform spherical, \code{"VI"} : spherical, \code{"EEE"} : uniform variance, 
\code{"VVV"} : unconstrained  variance, \code{"EFV"} : fixed (user supplied)
uniform volume, \code{"VFV"} : fixed (user supplied) shape.
}
\item{partition}{
initial classification of the data. The default puts every observation in a
singleton cluster.
}
\item{min.clusters}{
minimum number of clusters desired. The default is to carry out agglomerative
hierarchical clustering until termination, that is, until all observations
belong to a single group.
}
\item{verbose}{
A logical variable specifying printing of the model type when set to \code{T}.
}
\item{...}{
Allows users to specify the required \code{shape} parameter for the two fixed
shape models \code{"EFV"} and \code{"VFV"}, and to change default parameters
that are used in the algorithms underlying some models. In the 
\code{print.mhtree} function this argument is used for extra parameters to the print function.
}
\item{x}{
An \code{mhtree} object.}}
\value{
an object of class \code{"mhclust"}, which consists of a classification tree with
attributes giving other information relating to the clustering process.
}
\section{NOTES}{
Only the six models illustrated in the example below are supported at present.
These correspond to the models discussed in the Banfield and Raftery 
reference.
It may be desirable to transform the data in some way before attempting to 
partition it into clusters.
Different permuations of the data may produce different classifications,
because \code{mhclust} resolves ties in a way that is dependent on the order of the
observations, and because values of criterion that are close may change enough
to affect the choice of merge pairs in a given stage.
}
\references{
J. D. Banfield and A. E. Raftery, Model-based Gaussian and non-Gaussian
Clustering, \emph{Biometrics, }49:803-821 (September 1993).


C. Fraley, \emph{Algorithms for Model-based Gaussian Hierarchical Clustering,
}Technical Report No. 311, Department of Statistics, University of 
Washington (October 1996), to appear in
\emph{SIAM Journal on Scientific Computing}.
}
\seealso{
\code{\link{mhclass}}, \code{\link{loglik}}, \code{\link{awe}}, \code{\link{partuniq}}
}
\examples{
data(iris)

# Ellipsoidal, equal volume, shape and orientation
mhtree(iris[,1:4], modelid = "EEE")

# Spherical, equal volume, fixed shape, variable orientation
shape <- c(1,1/2,1/3,1/4)
mhtree(iris[,1:4], modelid = "EFV", shape=shape)

# Spherical, equal volume (Ward's method).
mhtree(iris[,1:4], modelid = "EI")

# Ellipsoidal, equal volume, constant shape, variable orientation
mhtree(iris[,1:4], modelid = "VFV", shape=shape)

# Spherical, variable volume
mhtree(iris[,1:4], modelid = "VI")

# Unconstrained (default).
mhtree(iris[,1:4], modelid = "VVV")

}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{mhtree.VFV}
\alias{mhtree.VFV}
\alias{mhtree.VEV}
\title{
Classification tree for hierarchical clustering for Gaussian models with
equal volume and constant shape. 
}
\description{
Computes a classification tree for agglomerative hierarchical clustering
using a Gaussian model in which clusters have a constant shape and are
of equal volume. 
}
\usage{
mhtree.VFV(data, partition, min.clusters = 1, shape, alpha = 1)
}

\arguments{
\item{data}{
matrix of observations.
}
\item{partition}{
initial classification of the data. The default puts every observation in a
singleton cluster.
}
\item{min.clusters}{
minimum number of clusters desired. The default is to carry out agglomerative
hierarchical clustering until termination, that is, until all observations
belong to a single group. The default value is 1.
}
\item{shape}{
positive vector of length equal to the dimension of the observations.
The values of \code{shape} should be proportional to the squares of the lengths
of the semi-major axes of the corresponding ellipsoid, and may be given in
any order. Note that \code{shape} is a required argument.
}
\item{alpha}{
The value \code{alpha} times the trace of the sample crossproduct matrix of all
the observations divided by product of the data dimensions, is used for the
purpose of initalization.
The default value is 1.
}}
\value{
an object of class \code{"mhtree"}, which consists of a classification tree with
the following attributes:

\item{call}{
a copy of the call to \code{mhtree.VFV}.
}
\item{change}{
value of the optimal change in likelihood at each stage.
}
\item{dimensions}{
the data dimensions.
}
\item{initial.partition}{
the partition at which agglomerative hierarchical clustering is initiated.
}}
\section{NOTES}{
The value \code{alpha} is needed because the criterion is not defined for singleton
clusters or clusters consisting only of points that coincide.
}
\references{
J. D. Banfield and A. E. Raftery, Model-based Gaussian and non-Gaussian
Clustering, \emph{Biometrics, }49:803-821 (1993).


C. Fraley, \emph{Algorithms for Model-based Gaussian Hierarchical Clustering,
}Technical Report No. 311, Department of Statistics, University of
Washington (October 1996), to appear in
\emph{SIAM Journal on Scientific Computing}.
}
\seealso{
\code{\link{mhtree}}, \code{\link{mhclass}}, \code{\link{awe}}, \code{\link{partuniq}}
}
\examples{
data(iris)
shape <- c(1,1/2,1/3)
mhtree.VFV(iris[,1:3], shape = shape)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{mhtree.VI}
\alias{mhtree.VI}
\title{
Classification tree for hierarchical clustering for Gaussian models with diagonal variance.
}
\description{
Computes a classification tree for agglomerative hierarchical clustering using 
a Gaussian model in
which clusters are spherical and may vary in volume volume.
}
\usage{
mhtree.VI(data, partition, min.clusters = 1, alpha = 1)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{partition}{
initial classification of the data. The default puts every observation in a
singleton cluster.
}
\item{min.clusters}{
minimum number of clusters desired. The default is to carry out agglomerative
hierarchical clustering until termination, that is, until all observations
belong to a single group. The default value is 1.
}
\item{alpha}{
The value \code{alpha} times the trace of the sample crossproduct matrix of all
the observations divided by the product of the data dimensions, is used for
the purpose of initalization.
The default value is 1.
}}
\value{
an object of class \code{"mhtree"}, which consists of a classification tree with
the following attributes:

\item{call}{
a copy of the call to \code{mhtree.VI}.
}
\item{change}{
value of the optimal change in likelihood at each stage.
}
\item{dimensions}{
the data dimensions.
}
\item{initial.partition}{
the partition at which agglomerative hierarchical clustering is initiated.
}}
\section{NOTES}{
The value \code{alpha} is needed because the criterion is not defined for singleton
clusters or clusters consisting only of points that coincide.
}
\references{
J. D. Banfield and A. E. Raftery, Model-based Gaussian and non-Gaussian
Clustering, \emph{Biometrics, }49:803-821 (1993).


C. Fraley, \emph{Algorithms for Model-based Gaussian Hierarchical Clustering,
}Technical Report No. 311, Department of Statistics, University of
Washington (October 1996), to appear in
\emph{SIAM Journal on Scientific Computing}.
}
\seealso{
\code{\link{mhtree}}, \code{\link{mhclass}}, \code{\link{awe}}, \code{\link{partuniq}}
}
\examples{
data(iris)
mhtree.VI(iris[,1:4])


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{mhtree.VVV}
\alias{mhtree.VVV}
\title{
Classification tree for hierarchical clustering for Gaussian models with unconstrained variance.
}
\description{
Computes a classification tree for agglomerative hierarchical clustering using
a Gaussian model in which volume, shape, and orientation may vary among 
clusters.
}
\usage{
mhtree.VVV(data, partition, min.clusters = 1, alpha = 1, beta = 1)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{partition}{
initial classification of the data. The default puts every observation in a
singleton cluster.
}
\item{min.clusters}{
minimum number of clusters desired. The default is to carry out agglomerative
hierarchical clustering until termination, that is, until all observations
belong to a single group. The default value is 1.
}
\item{alpha}{
The value \code{alpha} times the trace of the sample crossproduct matrix of all
the observations divided by the product of the data dimensions, is used for
the purpose of initalization.
The default value is 1.
}
\item{beta}{
The value \code{beta} times the trace of the sample crossproduct matrix for the
group divided by the number of observations in the group, is used for the
purpose of initialization.
The default value is 1.
}}
\value{
an object of class \code{"mhtree"}, which consists of a classification tree with
the following attributes:

\item{call}{
a copy of the call to \code{mhtree.VVV}.
}
\item{change}{
value of the optimal change in likelihood at each stage.
}
\item{dimensions}{
the data dimensions.
}
\item{initial.partition}{
the partition at which agglomerative hierarchical clustering is initiated.
}}
\section{NOTES}{
The values \code{alpha} and \code{beta} are needed since the criteria are not
defined for groups for which the rank of the sample cross product matrix is
less than the dimension of the observations.
}
\references{
J. D. Banfield and A. E. Raftery, Model-based Gaussian and non-Gaussian
Clustering, \emph{Biometrics, }49:803-821 (1993).


C. Fraley, \emph{Algorithms for Model-based Gaussian Hierarchical Clustering,
}Technical Report No. 311, Department of Statistics, University of
Washington (October 1996), to appear in
\emph{SIAM Journal on Scientific Computing}.


A. J. Scott and M. J. Simons, Clustering methods based on likelihood ratio
criteria, \emph{Biometrics, }27:387-397 (1971).
}
\seealso{
\code{\link{mhtree}}, \code{\link{mhclass}}, \code{\link{awe}}, \code{\link{partuniq}}
}
\examples{
data(iris)
mhtree.VVV(iris[,1:4])


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{mixproj}
\alias{mixproj}
\alias{mvn2plot}
\title{
Displays one standard deviation of an MVN mixture classification.
}
\description{
\code{mixproj} displays one standard deviation of an MVN mxiture
classification along with data in for selected pairs of
coordinates. Function \code{mvn2plot} is used to plot the confidence
ellipses.
}
\usage{
mixproj(data, ms, partition, dimens, scale = F, k = 15, xlim, ylim,
xlab, ylab, col=partition, pch=partition, \dots)
mvn2plot(mu, sigma, k, add=T, col=NULL, xlim=NULL, ylim=NULL, xlab=NULL,
ylab=NULL, \dots)
}

\arguments{
\item{data}{
a matrix of onservations.
}
\item{ms}{
The result of an \code{mstep} calculation (a list consisting of
\code{mu} and \code{sigma}).
}
\item{partition}{
A integer vector giving an initial classification for each observation.
}
\item{dimens}{
  A vector of length two giving the two variables of the data to be
  plotted. If not provided, a random selection of two variables is made.
  
}
\item{scale}{
A logical variable telling whether or not the same scale should be used for
both variables so as to preserve geometry. The default does not use the same 
scale.
}
\item{k}{
Number of subdivisions for plotting segments of ellipsoids. Default: 8.
}
\item{xlim, ylim, xlab, ylab, col, pch}{
Standard arguments to \code{plot} with default values.
}
\item{add}{Add ellipses from \code{mvn2plot} to the existing plot.}

\item{...}{
  Further arguments to \code{plot}.
}
\item{mu}{
  Cluster centers.
}
\item{sigma}{
  Cluster covariance matrices.}}
\seealso{
\code{\link{mstep}}, \code{\link{clpairs}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "VVV"),3)
z <- me( iris[,1:4], modelid = "VVV", ctoz(cl))
pars <- mstep(iris[,1:4], modelid="VVV", z)
mixproj(iris[,1:4], ms=pars, partition=ztoc(z), dimens=c(1,2))
### Plot only one cluster
mvn2plot(pars$mu[1:2,1], pars$sigma[1:2, 1:2, 1], 25, F, col="red")
}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.




\name{mstep.EEE}
\alias{mstep.EEE}
\title{
M-step for constant-variance MVN mixture models
}
\description{
M-step for estimating parameters given conditional probabilities in an MVN 
mixture model having constant variance and possibly one Poisson noise term.
}
\usage{
mstep.EEE(data, z, eps, equal = F, noise = F, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{z}{
matrix of conditional probabilities. \code{z} should have a row for each observation
in \code{data}, and a column for each component of the mixture.
}
\item{eps}{
Lower bound on the reciprocal condition estimate for the covariance estimate.
Default : \code{.Machine$double.eps}.
}
\item{equal}{
Logical variable indicating whether or not to assume equal proportions in the
mixture. Default : \code{F}.
}
\item{noise}{
Logical variable indicating whether or not to include a Poisson noise term in
the model. Default : \code{F}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{noise = T}). Default : determined by function \code{hypvol}
}}
\value{
A list whose components are the parameter estimates corresponding to \code{z}:

\item{mu}{
matrix whose columns are the Gaussian group means.
}
\item{sigma}{
group variance matrix.
}
\item{prob}{
probabilities (mixing proportions) for each group (present only when
\code{equal = T}).
The loglikelihood and reciprocal condition estimate are returned as attributes.
}}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley,
(1997).
}
\seealso{
\code{\link{mstep}}, \code{\link{me.EEE}}, \code{\link{estep.EEE}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "EEE"),3)
z <- me.EEE( iris[,1:4], ctoz(cl))
Mstep <- mstep.EEE(iris[,1:4], z)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{mstep.EEV}
\alias{mstep.EEV}
\title{
M-step for constant shape, constant volume MVN mixture models
}
\description{
M-step for estimating parameters given conditional probabilities in an MVN 
mixture model having constant shape, constant volume and possibly one Poisson 
noise term.
}
\usage{
mstep.EEV(data, z, eps, equal = F, noise = F, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{z}{
matrix of conditional probabilities. \code{z} should have a row for each observation
in \code{data}, and a column for each component of the mixture.
}
\item{eps}{
A 2-vector specifying lower bounds on the pth root of the volume of the
ellipsoids defining the clusters, where p is the data dimension, and on the
reciprocal condition number for the estimated shape of the covariance estimate.
Default: \code{c(.Machine$double.eps, .Machine$double.eps)}
}
\item{equal}{
Logical variable indicating whether or not to assume equal proportions in the
mixture. Default : \code{F}.
}
\item{noise}{
Logical variable indicating whether or not to include a Poisson noise term in
the model. Default : \code{F}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{noise = T}). Default : determined by function \code{hypvol}
}}
\value{
A list whose components are the parameter estimates corresponding to \code{z}:

\item{mu}{
matrix whose columns are the Gaussian group means.
}
\item{sigma}{
group variance matrix.
}
\item{prob}{
probabilities (mixing proportions) for each group (present only when
\code{equal = T}).
The loglikelihood and reciprocal condition estimate are returned as attributes.
}}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley,
(1997).
}
\seealso{
\code{\link{mstep}}, \code{\link{me.EEV}}, \code{\link{estep.XEV}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "VVV"),3)
z <- me.EEV( iris[,1:4], ctoz(cl))
mstep.EEV(iris[,1:4], z)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{mstep.EI}
\alias{mstep.EI}
\title{
M-step for spherical, constant-volume MVN mixture models
}
\description{
M-step for estimating parameters given conditional probabilities in an MVN 
mixture model having equal, spherical variances and possibly one Poisson noise
term.
}
\usage{
mstep.EI(data, z, eps, equal = F, noise = F, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{z}{
matrix of conditional probabilities. \code{z} should have a row for each observation
in \code{data}, and a column for each component of the mixture.
}
\item{eps}{
Lower bound on the estimated value of sigma-squared.
Default : \code{.Machine$double.eps}
}
\item{equal}{
Logical variable indicating whether or not to assume equal proportions in the
mixture. Default : \code{F}.
}
\item{noise}{
Logical variable indicating whether or not to include a Poisson noise term in
the model. Default : \code{F}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{noise = T}). Default : determined by function \code{hypvol}
}}
\value{
A list whose components are the parameter estimates corresponding to \code{z}:

\item{mu}{
matrix whose columns are the Gaussian group means.
}
\item{sigma}{
group variance matrix.
}
\item{prob}{
probabilities (mixing proportions) for each group (present only when
\code{equal = T}).
The loglikelihood and reciprocal condition estimate are returned as attributes.
}}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley,
(1997).
\code{mstep}, \code{me.EI}, \code{estep.EI}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "EI"),3)
z <- me.EI( iris[,1:4], ctoz(cl))
Mstep <- mstep.EI(iris[,1:4], z)
estep.EI( iris[,1:4], Mstep$mu, Mstep$sigma, Mstep$prob)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{mstep}
\alias{mstep}
\title{
M-step for parameterized MVN mixture models
}
\description{
M-step for estimating parameters given conditional probabilities in a
MVN mixture model with possibly one Poisson noise term.
}
\usage{
mstep(data, modelid, z, \dots)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{modelid}{
An integer specifying a parameterization of the MVN covariance matrix defined 
by volume, shape and orientation charactertistics of the underlying clusters. 
The allowed values for \code{modelid} and their interpretation are as follows:
\code{"EI"} : uniform spherical, \code{"VI"} : spherical, \code{"EEE"} : uniform variance,
\code{"VVV"} : unconstrained variance, \code{"EEV"} : uniform shape and volume,
\code{"VEV"} : uniform shape.
}
\item{z}{
matrix of conditional probabilities. \code{z} should have a row for each observation
in \code{data}, and a column for each component of the mixture.
}
\item{...}{
additional arguments, as follows:
}
\item{eps}{
Tolerance for determining singularity in the covariance matrix. The precise 
definition of \code{eps} varies the parameterization, each of which has a default.
}
\item{equal}{
Logical variable indicating whether or not to assume equal proportions in the
mixture. Default : \code{F}.
}
\item{noise}{
Logical variable indicating whether or not to include a Poisson noise term in
the model. Default : \code{F}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{noise = T}). Default : determined by function \code{hypvol}
}}
\value{
A list whose components are the parameter estimates corresponding to \code{z}:

\item{mu}{
matrix whose columns are the Gaussian group means.
}
\item{sigma}{
group variance matrix.
}
\item{prob}{
probabilities (mixing proportions) for each group (present only when
\code{equal = T}).
The loglikelihood is returned as an attribute.
}}
\section{NOTE}{
The reciprocal condition estimate returned as an attribute ranges in value
between 0 and 1. The closer this estimate is to zero, the more likely it is
that the corresponding EM result (and BIC) are contaminated by roundoff error.
}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley,
(1997).
}
\seealso{
\code{\link{me}}, \code{\link{estep}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "VVV"),3)
z <- me( iris[,1:4], modelid = "VVV", ctoz(cl))
pars <- mstep(iris[,1:4], modelid="VVV", z)

}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{mstep.VEV}
\alias{mstep.VEV}
\title{
M-step for constant shape, constant volume MVN mixture models
}
\description{
M-step for estimating parameters given conditional probabilities in an MVN 
mixture model having constant shape, constant volume and possibly one Poisson 
noise term.
}
\usage{
mstep.VEV(data, z, eps, tol, itmax, equal = F, noise = F, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{z}{
matrix of conditional probabilities. \code{z} should have a row for each observation
in \code{data}, and a column for each component of the mixture.
}
\item{eps}{
A 2-vector specifying lower bounds on the pth root of the volume of the 
ellipsoids defining the clusters, where p is the data dimension, and on the 
reciprocal condition number for the estimated shape of the covariance 
estimates. Default: \code{c(.Machine$double.eps, .Machine$double.eps)}
}
\item{tol}{
The iteration for volume/shape estimates is terminated if their relative
error is less than \code{tol}.
}
\item{itmax}{
The iteration for volume/shape estimates is terminated if the number of 
iterations exceeds \code{itmax}. Default: \code{Inf} (termination is determined by
\code{tol}).
}
\item{equal}{
Logical variable indicating whether or not to assume equal proportions in the
mixture. Default : \code{F}.
}
\item{noise}{
Logical variable indicating whether or not to include a Poisson noise term in
the model. Default : \code{F}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{noise = T}). Default : determined by function \code{hypvol}
}}
\value{
A list whose components are the parameter estimates corresponding to \code{z}:

\item{mu}{
matrix whose columns are the Gaussian group means.
}
\item{sigma}{
group variance matrix.
}
\item{prob}{
probabilities (mixing proportions) for each group (present only when
\code{equal = T}).
The loglikelihood and reciprocal condition estimate are returned as attributes.
}}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley,
(1997).
}
\seealso{
\code{\link{mstep}}, \code{\link{me.VEV}}, \code{\link{estep.XEV}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4]),3)
z <- me.VEV( iris[,1:4], ctoz(cl))
mstep.VEV(iris[,1:4], z)


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{mstep.VI}
\alias{mstep.VI}
\title{
M-step for spherical, varying volume MVN mixture models
}
\description{
M-step for estimating parameters given conditional probabilities in an MVN 
mixture model having varying spherical variances and possibly one Poisson noise
term.
}
\usage{
mstep.VI(data, z, eps, equal = F, noise = F, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{z}{
matrix of conditional probabilities. \code{z} should have a row for each observation
in \code{data}, and a column for each component of the mixture.
}
\item{eps}{
Lower bound on the estimated values of sigma-squared. 
Default : \code{.Machine$double.eps}
}
\item{equal}{
Logical variable indicating whether or not to assume equal proportions in the
mixture. Default : \code{F}.
}
\item{noise}{
Logical variable indicating whether or not to include a Poisson noise term in
the model. Default : \code{F}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{noise = T}). Default : determined by function \code{hypvol}
}}
\value{
A list whose components are the parameter estimates corresponding to \code{z}:

\item{mu}{
matrix whose columns are the Gaussian group means.
}
\item{sigma}{
group variance matrix.
}
\item{prob}{
probabilities (mixing proportions) for each group (present only when
\code{equal = T}).
The loglikelihood and reciprocal condition estimate are returned as attributes.
}}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley,
(1997).
}
\seealso{
\code{\link{mstep}}, \code{\link{me.VI}}, \code{\link{estep.VI}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "VI"),3)
z <- me.VI( iris[,1:4], ctoz(cl))
Mstep <- mstep.VI(iris[,1:4], z)
estep.VI( iris[,1:4], Mstep$mu, Mstep$sigma, Mstep$prob)

}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{mstep.VVV}
\alias{mstep.VVV}
\title{
M-step for unconstrained MVN mixture models
}
\description{
M-step for estimating parameters given conditional probabilities in an 
unconstrained MVN mixture model with possibly one Poisson noise term.
}
\usage{
mstep.VVV(data, z, eps, equal = F, noise = F, Vinv)


}
\arguments{
\item{data}{
matrix of observations.
}
\item{z}{
matrix of conditional probabilities. \code{z} should have a row for each observation
in \code{data}, and a column for each component of the mixture.
}
\item{eps}{
Lower bound on the reciprocal condition estimate for the covariance estimates.
Default : \code{.Machine$double.eps}.
}
\item{equal}{
Logical variable indicating whether or not to assume equal proportions in the
mixture. Default : \code{F}.
}
\item{noise}{
Logical variable indicating whether or not to include a Poisson noise term in
the model. Default : \code{F}.
}
\item{Vinv}{
An estimate of the inverse hypervolume of the data region (needed only if
\code{noise = T}). Default : determined by function \code{hypvol}
}}
\value{
A list whose components are the parameter estimates corresponding to \code{z}:

\item{mu}{
matrix whose columns are the Gaussian group means.
}
\item{sigma}{
group variance matrix.
}
\item{prob}{
probabilities (mixing proportions) for each group (present only when
\code{equal = T}).
The loglikelihood and reciprocal condition estimate are returned as attributes.
}}
\references{
G. Celeux and G. Govaert, Gaussian parsimonious clustering models,
\emph{Pattern Recognition, }28:781-793 (1995).


A. P. Dempster, N. M. Laird and D. B. Rubin, Maximum Likelihood from
Incomplete Data via the EM Algorithm, \emph{Journal of the Royal Statistical
Society, Series B, }39:1-22 (1977).


G. J. MacLachlan and K. E. Basford, The EM Algorithm and Extensions, Wiley,
(1997).
}
\seealso{
\code{\link{mstep}}, \code{\link{me.VVV}}, \code{\link{estep.VVV}}
}
\examples{
data(iris)
cl <- mhclass(mhtree(iris[,1:4], modelid = "VVV"),3)
z <- me.VVV( iris[,1:4], ctoz(cl))
Mstep <- mstep.VVV(iris[,1:4], z)
estep.VVV( iris[,1:4], Mstep$mu, Mstep$sigma, Mstep$prob)

}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{one.XXX}
\alias{one.XXX}
\alias{one.XI}

\title{Log-likelihood for a single cluster}
\description{
  \code{one.XXX} calculates the log-likelihood for a single
  unconstrained Gaussian cluster; \code{one.XI} calculates the
  log-likelihood for a single Gaussian spherical cluster.
}
\usage{
one.XXX(data)
one.XI(data)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{data}{}
}

\examples{
data(iris)
one.XI(iris[,1:4])
one.XXX(iris[,1:4])
}
\keyword{cluster}
\name{partconv}
\alias{partconv}

\title{Convert partitioning into numerical vector.}
\description{\code{partconv} converts a partitioning into a numerical
  vector. The second argument is used to force consecutive numbers
  (default) or not.
}
\usage{
partconv(x, consec=T)
}

\arguments{
  \item{x}{Partitioning. Maybe numerical or not.}
  \item{consec}{Logical flag, whether or not to use consecutive class
    numbers.}
}
\value{
  Vector of class numbers.
}

\examples{
data(iris)
partconv(iris[,5])

cl _ sample(1:10, 25, replace=T)
partconv(cl, consec=F)
partconv(cl, consec=T)
}

\keyword{cluster}
\name{partuniq}
\alias{partuniq}
\title{
Classifies Data According to Unique Observations
}
\description{
Gives a one-to-one mapping from unique observations to rows of a data matrix.
}
\usage{
partuniq(x, sep="001")
}
\arguments{
  \item{x}{Matrix of observations.}
  \item{sep}{Separation string.}
}
\value{
A vector of length \code{nrow(x)} with integer entries. An observation
\code{k} is assigned an integer \code{i} whenever observation \code{i}
is the first row of \code{x} that is identical to observation \code{k}
(note that \code{i <= k}).
}
\examples{
data(iris)
mhtree(iris[,1:4], partition = partuniq(iris[,1:4]))


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{plot.emclust}
\alias{plot.emclust}
\alias{plot.emclust1}

\title{Plot BIC values}
\description{

}
\usage{
plot.emclust(x, xlab="number of clusters", ylab="BIC", pch, ...)
plot.emclust1(x, xlab = "number of clusters", ylab="BIC", ...)
}
\arguments{
  \item{x}{\code{emclust} object containing BIC values.}
  \item{xlab, ylab, pch}{Standard plot arguments with default values.}
  \item{\dots}{Further arguments to the plot function.}
}

\seealso{\code{\link{emclust}}, \code{\link{emclust1}}}

\examples{
data(iris)
bicvals _ emclust(iris[,1:4], nclus=1:3, modelid=c("VVV","EEV","VEV"))
plot(bicvals, col=c("red","cyan","purple"), lty=1)
}
\keyword{cluster}
\name{print.emclust}
\alias{print.emclust}
\alias{print.emclust1}
\alias{print.bic}

\title{Print methods for BIC values}
\description{
  Print objects from \code{emclust}, \code{emclust1} or \code{bic}.
}
\usage{
print.emclust(x, ...)
print.emclust1(x, ...)
print.bic(x, ...)
}

\arguments{
  \item{x}{Object containing BIC values}
  \item{\dots}{Further arguments to print.default}
}

\keyword{cluster}
\name{summary.emclust}
\alias{summary.emclust}
\alias{print.summary.emclust}
\title{
Summary method for `emclust' objects.
}
\description{
Optimal model parameters for \code{emclust} objects.
}
\usage{
summary.emclust(object, data, nclus, modelid, \dots)
print.summary.emclust(x, \dots)
}
\arguments{
  \item{object}{an \code{emclust} or a \code{summary.emclust} object.}
  \item{x}{an \code{emclust} or a \code{summary.emclust} object.}
  \item{data}{the data used to obtain the \code{emclust} object.}
  \item{nclus}{
    a vector of integers giving the number of clusters over which the
    summary is to take place (must be a subset of the column names of
    \code{object}). The default is to summarize over all numbers of clusters
    used in the original analysis.
  }
  \item{modelid}{
    a vector of character strings denoting the models over which the
    summary is to take place (must be a subset of the row names of
    \code{object}). The default is to summarize over all models used in
    the original analysis. 
  }
  \item{\dots}{
    Further (standard) arguments to the \code{print} function.}}
\value{
  A list giving the optimal (according to BIC) parameter and z values, 
  together with the associated classification and its uncertainty.
}
\seealso{
\code{\link{emclust}}
}
\examples{
data(iris)
iris.bic <- emclust(iris[,1:4], nclus=3:5)
summary(iris.bic, iris[,1:4])


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{summary.emclust1}
\alias{summary.emclust1}
\alias{print.summary.emclust1}
\title{
Summary method for `emclust1' objects.
}
\description{
Optimal model parameters for \code{emclust1} objects.
}
\usage{
summary.emclust1(object, data, nclus, \dots)
print.summary.emclust1(x, \dots)
}

\arguments{
  \item{object}{an \code{emclust1} or a \code{summary.emclust1} object.}
  \item{x}{an \code{emclust1} or a \code{summary.emclust1} object.}
  \item{data}{the data used to obtain the \code{emclust1} object.}
  \item{nclus}{
    a vector of integers giving the number of clusters over which the
    summary is to take place (must be a subset of the column names of
    \code{object}). The default is to summarize over all numbers of clusters
    used in the original analysis. 
  }
  \item{modelid}{
    a vector of character strings denoting the models over which the
    summary is to take place (must be a subset of the row names of
    \code{object}). 
  }
  \item{\dots}{Further (standard) arguments to the \code{print} function.}}
\value{
  A list giving the optimal (according to BIC) parameter and z values,
  together with the associated classification and its uncertainty.
}
\seealso{
\code{\link{emclust1}}
}
\examples{
data(iris)
iris.bic <- emclust(iris[,1:4], nclus=3:5)
summary(iris.bic, iris[,1:4])


}
\keyword{cluster}
% Converted by Sd2Rd version 0.3-2.


\name{traceW}
\alias{traceW}
\title{Compute traceW}
\description{
  Computes the trace of the sample cross product matrix.
}

\usage{traceW(x)}

\arguments{\item{x}{Data matrix}}

\examples{
data(iris)
traceW(as.matrix(iris[,1:4]))
}
\keyword{cluster}
\name{ztoc}
\alias{ztoc}
\alias{ctoz}
\title{Conversion between conditional probabilities and a classification}
\description{The function ctoz converts a discrete classification into
  the corresponding z matrix. ztoc converts a z matrix to the nearest
  classification. 
}
\usage{
ztoc(z)
ctoz(cl, noise)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{z}{Matrix with conditional probabilities; each object one row,
    and each cluster one column.}
  \item{cl}{Classification vector.}
  \item{noise}{Noise indicator vector.}
}

\examples{
data(iris)
cltree _ mhtree(iris[,1:4], modelid="VVV")
cl _ mhclass(cltree, 3)
origz _ ctoz(cl)
z _ me(iris[,1:4], modelid="VVV", origz)
newcl _ ztoc(z)
}
\keyword{cluster}%-- one or more ...
